==> zio-aws-networkmanager_3-5.17.154.1-sources.jar: zio/aws/networkmanager/model/CreateConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CreateConnectPeerResponse(
    connectPeer: Option[zio.aws.networkmanager.model.ConnectPeer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse = {
    import CreateConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
      .builder()
      .optionallyWith(connectPeer.map(value => value.buildAwsValue()))(
        _.connectPeer
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateConnectPeerResponse.wrap(buildAwsValue())
}
object CreateConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CreateConnectPeerResponse =
      zio.aws.networkmanager.model
        .CreateConnectPeerResponse(connectPeer.map(value => value.asEditable))
    def connectPeer: Option[zio.aws.networkmanager.model.ConnectPeer.ReadOnly]
    def getConnectPeer: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.ConnectPeer.ReadOnly
    ] = AwsError.unwrapOptionField("connectPeer", connectPeer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ) extends zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly {
    override val connectPeer
        : Option[zio.aws.networkmanager.model.ConnectPeer.ReadOnly] = scala
      .Option(impl.connectPeer())
      .map(value => zio.aws.networkmanager.model.ConnectPeer.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ): zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-5.19.7.6-sources.jar: zio/aws/networkmanager/model/CreateConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class CreateConnectPeerResponse(
    connectPeer: Optional[zio.aws.networkmanager.model.ConnectPeer] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse = {
    import CreateConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
      .builder()
      .optionallyWith(connectPeer.map(value => value.buildAwsValue()))(
        _.connectPeer
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.CreateConnectPeerResponse.wrap(buildAwsValue())
}
object CreateConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.CreateConnectPeerResponse =
      zio.aws.networkmanager.model
        .CreateConnectPeerResponse(connectPeer.map(value => value.asEditable))
    def connectPeer: Optional[zio.aws.networkmanager.model.ConnectPeer.ReadOnly]
    def getConnectPeer: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.ConnectPeer.ReadOnly
    ] = AwsError.unwrapOptionField("connectPeer", connectPeer)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ) extends zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly {
    override val connectPeer
        : Optional[zio.aws.networkmanager.model.ConnectPeer.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.connectPeer())
        .map(value => zio.aws.networkmanager.model.ConnectPeer.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.CreateConnectPeerResponse
  ): zio.aws.networkmanager.model.CreateConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}
